#[non_exhaustive]pub enum ChunkedUploadError {
Io(Error),
SessionNotFound(String),
InvalidChunk {
expected: usize,
actual: usize,
},
ChunkOutOfOrder {
expected: usize,
actual: usize,
},
AlreadyCompleted,
ChecksumMismatch,
DuplicateChunk {
chunk_number: usize,
},
}Expand description
Errors that can occur during chunked upload
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
An I/O error occurred during chunk processing.
SessionNotFound(String)
The upload session with the given ID was not found.
InvalidChunk
The received chunk size does not match the expected size.
Fields
ChunkOutOfOrder
Chunks were received out of sequential order.
AlreadyCompleted
The upload session has already been completed.
ChecksumMismatch
The assembled file checksum does not match the expected value.
DuplicateChunk
A chunk with the same number has already been uploaded.