pub struct TrustedProxies { /* private fields */ }Expand description
Configuration for trusted proxy IPs.
Only proxy headers (X-Forwarded-For, X-Real-IP, X-Forwarded-Proto) from these IP addresses will be trusted. By default, no proxies are trusted and the actual connection information is used.
Implementations
Sourceimpl TrustedProxies
impl TrustedProxies
Sourcepub fn new(ips: impl IntoIterator<Item = IpAddr>) -> Self
pub fn new(ips: impl IntoIterator<Item = IpAddr>) -> Self
Create with a set of trusted proxy IPs.
Sourcepub fn is_trusted(&self, addr: &IpAddr) -> bool
pub fn is_trusted(&self, addr: &IpAddr) -> bool
Check if the given address is a trusted proxy.
Sourcepub fn has_trusted_proxies(&self) -> bool
pub fn has_trusted_proxies(&self) -> bool
Check if any proxies are configured.