TrustedProxies

Struct TrustedProxies 

pub struct TrustedProxies { /* private fields */ }
Configuration for trusted proxy IPs.

Only proxy headers (X-Forwarded-For, X-Real-IP, X-Forwarded-Proto) from these IP addresses will be trusted. By default, no proxies are trusted and the actual connection information is used.

Implementations

Source

impl TrustedProxies

pub fn none() -> Self

Create with no trusted proxies (default, most secure).

pub fn new(ips: impl IntoIterator<Item = IpAddr>) -> Self

Create with a set of trusted proxy IPs.

pub fn is_trusted(&self, addr: &IpAddr) -> bool

Check if the given address is a trusted proxy.

pub fn has_trusted_proxies(&self) -> bool

Check if any proxies are configured.