Structs
- Response
- HTTP Response representation
- Safe
Error Response - Builder for creating error responses that prevent information leakage.
- Streaming
Response - Streaming HTTP Response
Functions
- truncate_
for_ log - Truncate a string for safe inclusion in log messages.
Type Aliases
- Stream
Body - Type alias for streaming body