Module response

Module response 

HTTP response type and builder.

Structs

Response
HTTP Response representation
SafeErrorResponse
Builder for creating error responses that prevent information leakage.
StreamingResponse
Streaming HTTP Response

Functions

truncate_for_log
Truncate a string for safe inclusion in log messages.

Type Aliases

StreamBody
Type alias for streaming body